# プロダクトコンテキスト

## 解決する問題

1. **ボイラープレートコードの削減**
   - 各種ライブラリを使用する際の定型的なコードを減らす
   - 共通パターンを再利用可能な形で提供

2. **一貫性の確保**
   - 異なるライブラリ間での操作を統一的に扱う
   - プロジェクト全体で一貫したコーディングスタイルを維持

3. **開発効率の向上**
   - 頻繁に使用される機能をユーティリティとして提供
   - モジュール化された構造により必要な機能を素早く見つけられる

4. **依存関係の最適化**
   - 必要な機能のみをインストール可能
   - 不要なライブラリのインストールを防ぐ

## 使用方法

### 基本的な使用パターン

```python
# ライブラリ固有のユーティリティ
import pytilpack.xxx_  # xxxは各ライブラリ名（openai, pathlib等）

# 汎用ユーティリティ
import pytilpack.xxx   # 特定のライブラリに依存しない機能
```

### インストールオプション

- 最小インストール: `pip install pytilpack`
- 全機能インストール: `pip install pytilpack[all]`
- 個別機能インストール: `pip install pytilpack[機能名]`
  - 例: `pip install pytilpack[fastapi]`

### 主要な機能グループ

1. **標準ライブラリ拡張**
   - asyncio_, pathlib_, threading_等の拡張機能
   - 一般的な操作のための便利な関数群

2. **Webフレームワークサポート**
   - FastAPI, Flask, Quartのユーティリティ
   - 認証、ルーティング等の共通機能

3. **データ処理ユーティリティ**
   - JSON, YAML, CSVの操作
   - データURLやHTMLのRAG処理

## 想定される利用シーン

- Webアプリケーション開発
- データ処理スクリプト作成
- 自動化ツール開発
- マイクロサービス実装

## ユーザー体験目標

- 直感的なAPIの提供
- 最小限の学習コストで利用可能
- 必要な機能への素早いアクセス
- 柔軟な機能選択とカスタマイズ
